==> cayenne-3.0.2-src.tar.gz: cayenne-3.0.2-src/framework/cayenne-jdk1.5-unpublished/src/test/java/org/apache/cayenne/map/RelationshipTest.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.map;

import org.apache.cayenne.unit.CayenneCase;

public class RelationshipTest extends CayenneCase {

    public void testName() throws Exception {
        Relationship rel = new MockRelationship();

        String tstName = "tst_name";
        rel.setName(tstName);
        assertEquals(tstName, rel.getName());
    }

    public void testSourceEntity() {
        Relationship rel = new MockRelationship();
        Entity tstEntity = new MockEntity();
        rel.setSourceEntity(tstEntity);
        assertSame(tstEntity, rel.getSourceEntity());
    }

    public void testTargetEntity() {
        Relationship rel = new MockRelationship();
        Entity tstEntity = new MockEntity();
        tstEntity.setName("abc");
        rel.setTargetEntity(tstEntity);
        assertSame("abc", rel.getTargetEntityName());
    }

    public void testTargetEntityName() {
        Relationship rel = new MockRelationship();
        rel.setTargetEntityName("abc");
        assertSame("abc", rel.getTargetEntityName());
    }
}

==> cayenne-3.1.3-src.tar.gz: cayenne-3.1.3-src/framework/cayenne-jdk1.5-unpublished/src/test/java/org/apache/cayenne/map/RelationshipTest.java <==
/*****************************************************************
 *   Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 ****************************************************************/

package org.apache.cayenne.map;

import junit.framework.TestCase;

public class RelationshipTest extends TestCase {

    public void testName() throws Exception {
        Relationship rel = new MockRelationship();

        String tstName = "tst_name";
        rel.setName(tstName);
        assertEquals(tstName, rel.getName());
    }

    public void testSourceEntity() {
        Relationship rel = new MockRelationship();
        Entity tstEntity = new MockEntity();
        rel.setSourceEntity(tstEntity);
        assertSame(tstEntity, rel.getSourceEntity());
    }

    public void testTargetEntity() {
        Relationship rel = new MockRelationship();
        Entity tstEntity = new MockEntity();
        tstEntity.setName("abc");
        rel.setTargetEntity(tstEntity);
        assertSame("abc", rel.getTargetEntityName());
    }

    public void testTargetEntityName() {
        Relationship rel = new MockRelationship();
        rel.setTargetEntityName("abc");
        assertSame("abc", rel.getTargetEntityName());
    }
}
